from packgram import ProjectModule


# TODO: return target in render_file?
# TODO: return render_dir?
class ProjectModule(ProjectModule):

    # Attributes

    author = 'roll'
    author_email = 'roll@respect31.com'
    copyright = 'Copyright (c) 2014 Respect31 <post@respect31.com>'
    description = 'Run-render is a plugin for Run.'
    development_requires = ['packgram>=0.25']
    github_user = 'run-hub'
    install_requires = ['sugarbowl', 'runfile', 'run-function', 'jinja2']
    interpreters = ['3.3', '3.4']
    license = 'MIT License'
    name = 'run-render'
    platforms = ['Unix']
    pypi_password_secure = 'pdoipmwGPkc5u/kw+wZSvLaPHtBEnBvswTWgloMTa5sqxZPek1xYKVHiXl3yYXl+ZRfIgNcDNInKzCN9TGl3R56BKuOmrMACy9WqqhI+vpEW+i8ewLDzSXZ4Y48chBMC2TJmRec4VQhME5RfCJFq7Fi7CjfclMSixxBQ0NYc4So='
    tests_require = ['nose', 'coverage']
    test_suite = 'nose.collector'
    version = '0.5.0'
